function [ u ] = u_function(k, h, n, j, uc)
%U_FUNCTION This function returns the single value of u given the specified 
%index in time and space, n and j

%Input:
%k is the step size in time
%h is the step size in space
%n is the specified index in time
%j is the specified index in space
%uc is the current matrix of approximate solutions

%Output:
%u is a single value at the specified index in time and space, n and j

x = 0 + j*h;
t = 0 + n*k;

%If the specified index in time and space, n and j, do not refer to a 
%boundary value of u, then set the value of u to be the value of n, j in
%the current matrix of approximate solutions
if(isnan(uboundary(k, h, n, j)) == 1)
    
    u = uc(n, j);
    
end;

%If the specified index in time and space, n and j, do refer to a 
%boundary value of u, then set the value of u to be the value of n, j at
%the boundary
if(isnan(uboundary(k, h, n, j)) == 0)
    
    u = uboundary(k, h, n, j);
    
end;

end

